﻿
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Net;
using System.IO;
using System.Net.Sockets;

namespace VZInterfaceTestHandbook
{
  public partial class EthCom : IComIf
  {
    TcpClient tcpClient = new TcpClient();
    Stream tcpStream;
    string tcpIp = "127.0.0.1";
    int tcpPort = 50915;

    /**
     * Open the connection
     */
    public Boolean Open()
    {
      try
      {
        if (isConnected())
          Close();
        tcpClient.Connect(tcpIp, tcpPort);
        tcpStream = tcpClient.GetStream();
      }
      catch (Exception e)
      {
        Console.WriteLine(e.ToString());
      }
      return !isConnected();
    }

    /**
     * Close the connection
     */
    public Boolean Close()
    {
      try
      {
        tcpStream.Close();
        tcpClient.Close();
        // Close also disposes the tcp client ... so this is a nice hack
        tcpClient = new TcpClient();
      }
      catch (Exception)
      {
      }
      return false;
    }

    public void Configure(string strIp, int iPort)
    {
      tcpIp = strIp;
      tcpPort = iPort;
    }

    public InterfaceType GetInterfaceType()
    {
      return InterfaceType.ETH;
    }

    /**
     * Required by interface
     */
    public Boolean SetBaudrate(int baudRate)
    {
      return false;
    }

    /**
     * Check connection
     * @return connected = true
     */
    public Boolean isConnected()
    {
      return tcpClient.Connected;
    }

    /**
     * Write bytes
     * @param buffer: bytes to write
     * @param count: number of bytes
     * @return: success = false
     */
    public Boolean Write(Byte[] buffer, int count)
    {
      if (!isConnected())
        return true;
      try
      {
        tcpStream.Write(buffer, 0, count);
      }
      catch (Exception)
      {
        return true;
      }

      return false;
    }

    /**
     * Set the timeout
     * @param timeout: in ms
     */
    public Boolean ReadTimeout(int timeout)
    {
      if (timeout > 0)
        tcpStream.ReadTimeout = timeout;
      return false;
    }

    /**
     * @return Number of bytes available for read
     */
    public int BytesToRead()
    {
      int iToRead = 0;

      if (!isConnected())
        return 0;
      try
      {
        iToRead = tcpClient.Available;
      }
      catch (Exception)
      {
      }

      return iToRead;
    }

    /**
     * Clear queue 
     */
    public void Flush()
    {
      if (!isConnected())
        return;
      try
      {
        tcpStream.Flush();
      }
      catch (Exception)
      {
      }
    }

    /**
     * Read bytes currently available
     * @param buffer: to be filled
     * @param count: number of bytes to be read
     * @return read bytes
     */
    public int Read(out Byte[] buffer, int count)
    {
      Byte[] buf = new Byte[count];

      int iRead;
      if (!isConnected())
      {
        buffer = null;
        return -1;
      }

      try
      {
        iRead = tcpStream.Read(buf, 0, count);
      }
      catch (Exception e)
      {
        System.Console.WriteLine(e.ToString()); //Exception-outline
        buffer = null;
        return -1;
      }

      buffer = buf;
      return iRead;
    }

    /**
     * Read one byte
     * @param byteRecv: to be filled
     */

    public Boolean ReadByte(ref Byte byteRecv)
    {
      if (!isConnected())
        return true;
      try
      {
        byteRecv = (Byte)tcpStream.ReadByte();
      }
      catch (Exception)
      {
        return true;
      }

      return false;
    }
  }
}
