﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace VZInterfaceTestHandbook
{
  public partial class FormEthernet : Form
  {
    IComIf comIf;

    public FormEthernet(IComIf com)
    {
      InitializeComponent();
      comIf = com;
      if (connOpen())
        return;
      timerEthernet.Start();
    }

    /**
     * Open connection
     * @return success = false
     */
    private Boolean connOpen()
    {
      if (comIf.Open())
      {
        MessageBox.Show("Couldn´t open interface!", "Error",
                        MessageBoxButtons.OK,
                        MessageBoxIcon.Error);
        return true;
      }
      return false;
    }

    /**
     * Close connection
     */
    private void connClose()
    {
      comIf.Close();
    }

    private void timerEthernet_Tick(object sender, EventArgs e)
    {
      BlockCommands bc = new BlockCommands(comIf);
      Byte[] buf;

      buf = bc.Ethernet2();
      if (buf == null)
      {
        timerEthernet.Stop();
        connClose();
        return;
      }

      //d0
      comboBoxEthernetMode.SelectedIndex = (buf[4] & 0x1E) >> 1;
      if ((buf[4] & 0x01) == 0x01)
        checkBoxDhcp.Checked = true;
      else
        checkBoxDhcp.Checked = false;
      //d1
      comboBoxStreamingResoLegacy.SelectedIndex = buf[5];
      //d2
      comboBoxFrameRate.SelectedIndex = (buf[6] & 0xF0) >> 4;
      comboBoxStreamingMode.SelectedIndex = buf[6] & 0x0F;
      //d3
      //d4-7
      textBoxIpAddress.Text = Convert.ToUInt32(buf[8]) + "." + Convert.ToUInt32(buf[9]) + "." + Convert.ToUInt32(buf[10]) + "." + Convert.ToUInt32(buf[11]);
      //d8-11
      textBoxSubnet.Text = Convert.ToUInt32(buf[12]) + "." + Convert.ToUInt32(buf[13]) + "." + Convert.ToUInt32(buf[14]) + "." + Convert.ToUInt32(buf[15]);
      //d12-15
      textBoxGateway.Text = Convert.ToUInt32(buf[16]) + "." + Convert.ToUInt32(buf[17]) + "." + Convert.ToUInt32(buf[18]) + "." + Convert.ToUInt32(buf[19]);
      //d16-19
      textBoxDestination.Text = Convert.ToUInt32(buf[20]) + "." + Convert.ToUInt32(buf[21]) + "." + Convert.ToUInt32(buf[22]) + "." + Convert.ToUInt32(buf[23]);
      //d20-21
      uint iPort = Convert.ToUInt32(buf[24] << 8)
                 + Convert.ToUInt32(buf[25] << 0);
      textBoxPort.Text = iPort.ToString();
      //d22-25
      int iIdxStream = Convert.ToInt32(buf[26] << 24)
               + Convert.ToInt32(buf[27] << 16)
               + Convert.ToInt32(buf[28] << 8)
               + Convert.ToInt32(buf[29] << 0);
      comboBoxResolution.SelectedIndex = getCbIndexStreamingReso(iIdxStream);
      //d26
      comboBoxFormat.SelectedIndex = buf[30];
      //d27-30
      textBoxNameserver.Text = Convert.ToUInt32(buf[31]) + "." + Convert.ToUInt32(buf[32]) + "." + Convert.ToUInt32(buf[33]) + "." + Convert.ToUInt32(buf[34]);
    }

    /**
     * Convert Wolfprot parameter to combobox index
     * @param iIdx: Wolfprot parameter
     * @return combobox index
     */
    private int getCbIndexStreamingReso(int iIdx)
    {
      switch (iIdx)
      {
        case 0x00000018:
          return 0;
        case 0x00000016:
          return 1;
        case 0x00000020:
          return 2;
        case 0x00000021:
          return 3;
        case 0x00010018:
          return 4;
        case 0x00020018:
          return 5;
        case 0x00030018:
          return 6;
        case 0x00040018:
          return 7;
        case 0x00050018:
          return 8;
        case 0x00100018:
          return 9;
        case 0x00110018:
          return 10;
        case 0x00120018:
          return 11;
        case 0x00130018:
          return 12;
        case 0x00140018:
          return 13;
        default:
          return 0;
      }
    }

    private void buttonReturn_Click(object sender, EventArgs e)
    {
      timerEthernet.Stop();
      connClose();
      Close();
    }
  }
}
