﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace VZInterfaceTestHandbook
{

  public partial class FormFlagsAndUnits : Form
  {
    IComIf comIf;

    public FormFlagsAndUnits(IComIf com)
    {
      InitializeComponent();
      comIf = com;
      if (connOpen())
        return;
      timerFlagsAndUnits.Start();
    }

    /**
     * Open connection
     * @return success = false
     */
    private Boolean connOpen()
    {
      if (comIf.Open())
      {
        MessageBox.Show("Couldn´t open interface!", "Error",
                        MessageBoxButtons.OK,
                        MessageBoxIcon.Error);
        return true;
      }
      return false;
    }

    /**
     * Close connection
     */
    private void connClose()
    {
      comIf.Close();
    }

    private void buttonReturn_Click(object sender, EventArgs e)
    {
      timerFlagsAndUnits.Stop();
      connClose();
      Close();
    }

    private void timerFlagsAndUnits_Tick(object sender, EventArgs e)
    {
      BlockCommands bc = new BlockCommands(comIf);
      Byte[] buf;

      buf = bc.FlagsAndUnits2();
      if (buf == null)
      {
        timerFlagsAndUnits.Stop();
        connClose();
        return;
      }

      //d0
      if ((buf[4] & 0x80) == 0x80)
        checkBoxPower.Checked = true;
      else
        checkBoxPower.Checked = false;
      if ((buf[4] & 0x40) == 0x40)
        checkBoxLight.Checked = true;
      else
        checkBoxLight.Checked = false;
      if ((buf[4] & 0x20) == 0x20)
        checkBoxLightbox.Checked = true;
      else
        checkBoxLightbox.Checked = false;
      if ((buf[4] & 0x10) == 0x10)
        checkBoxSlidebox.Checked = true;
      else
        checkBoxSlidebox.Checked = false;
      if ((buf[4] & 0x08) == 0x08)
        checkBoxAf.Checked = true;
      else
        checkBoxAf.Checked = false;
      if ((buf[4] & 0x04) == 0x04)
        checkBoxAe.Checked = true;
      else
        checkBoxAe.Checked = false;
      if ((buf[4] & 0x02) == 0x02)
        checkBoxTextEnhancer.Checked = true;
      else
        checkBoxTextEnhancer.Checked = false;
      if ((buf[4] & 0x01) == 0x01)
        checkBoxExtern.Checked = true;
      else
        checkBoxExtern.Checked = false;
      //d1
      if ((buf[5] & 0x80) == 0x80)
        checkBoxFreeze.Checked = true;
      else
        checkBoxFreeze.Checked = false;
      if ((buf[5] & 0x40) == 0x40)
        checkBoxImage.Checked = true;
      else
        checkBoxImage.Checked = false;
      if ((buf[5] & 0x20) == 0x20)
        checkBoxView.Checked = true;
      else
        checkBoxView.Checked = false;
      if ((buf[5] & 0x10) == 0x10)
        checkBoxKeylock.Checked = true;
      else
        checkBoxKeylock.Checked = false;
      if ((buf[5] & 0x08) == 0x08)
        checkBoxLampBlown.Checked = true;
      else
        checkBoxLampBlown.Checked = false;
      if ((buf[5] & 0x04) == 0x04)
        checkBoxLamp2Blown.Checked = true;
      else
        checkBoxLamp2Blown.Checked = false;
      if ((buf[5] & 0x02) == 0x02)
        checkBoxLamp1Blown.Checked = true;
      else
        checkBoxLamp1Blown.Checked = false;
      if ((buf[5] & 0x01) == 0x01)
        checkBoxOsdMenu.Checked = true;
      else
        checkBoxOsdMenu.Checked = false;
      //d2
      comboBoxColorMode.SelectedIndex = (buf[6] & 0xF0) >> 4;
      comboBoxPosNegBlue.SelectedIndex = (buf[6] & 0x0C) >> 2;
      comboBoxImageTurn.SelectedIndex = buf[6] & 0x03;
      //d3
      //d4
      comboBoxFrameNumber.SelectedIndex = buf[8] & 0x0F;
      //d5
      comboBoxEthernetMode.SelectedIndex = buf[9];
      //d6
      comboBoxDviLegacy.SelectedIndex = buf[10];
      //d7
      comboBoxRgbLegacy.SelectedIndex = buf[11];
      //d8-11
      uint iSerialNumber = Convert.ToUInt32(buf[12] << 24)
                          + Convert.ToUInt32(buf[13] << 16)
                          + Convert.ToUInt32(buf[14] << 8)
                          + Convert.ToUInt32(buf[15] << 0);
      textBoxSerialNumber.Text = iSerialNumber.ToString();
      //d12-18
      textBoxVersion.Text = System.Text.Encoding.ASCII.GetString(buf).Substring(16, 7);
      //d19
      comboBoxMemory.SelectedIndex = (buf[23] & 0xF0) >> 4;
      if ((buf[23] & 0x08) == 0x08)
        checkBoxMemoryZoom.Checked = true;
      else
        checkBoxMemoryZoom.Checked = false;
      if ((buf[23] & 0x04) == 0x04)
        checkBoxPip.Checked = true;
      else
        checkBoxPip.Checked = false;
      comboBoxMenu.SelectedIndex = buf[23] & 0x03;
      //d20
      comboBoxSource.SelectedIndex = (buf[24] & 0xC0) >> 6;
      if ((buf[24] & 0x20) == 0x20)
        checkBoxDeepPowerDown.Checked = true;
      else
        checkBoxDeepPowerDown.Checked = false;
      if ((buf[24] & 0x10) == 0x10)
        checkBoxMemUsbFullscreen.Checked = true;
      else
        checkBoxMemUsbFullscreen.Checked = false;
      if ((buf[24] & 0x08) == 0x08)
        checkBoxMemUsb.Checked = true;
      else
        checkBoxMemUsb.Checked = false;
      if ((buf[24] & 0x04) == 0x04)
        checkBoxSlideShow.Checked = true;
      else
        checkBoxSlideShow.Checked = false;
      comboBoxAspectRatio.SelectedIndex = buf[24] & 0x03;
      //d21
      textBoxHdtvMaskPosition.Text = Convert.ToByte(buf[25]).ToString();
      //d22 not used
      //d23-24
      uint iStatusNumber = Convert.ToUInt32(buf[27] << 8)
                          + Convert.ToUInt32(buf[28] << 0);
      textBoxStatusNumber.Text = iStatusNumber.ToString();
      //d25
      textBoxStatusTime.Text = ((buf[29] & 0xFC) >> 2).ToString();
      comboBoxStatusLevel.SelectedIndex = buf[29] & 0x03;
      //d26-27
      uint iStatusTimeStamp = Convert.ToUInt32(buf[30] << 8)
                          + Convert.ToUInt32(buf[31] << 0);
      textBoxStatusTimeStamp.Text = iStatusTimeStamp.ToString();
      //d28-35
      textBoxStatusSubText.Text = System.Text.Encoding.ASCII.GetString(buf).Substring(32, 8);
      //d36-39
      int iIdxMain = Convert.ToInt32(buf[40] << 24)
               + Convert.ToInt32(buf[41] << 16)
               + Convert.ToInt32(buf[42] << 8)
               + Convert.ToInt32(buf[43] << 0);
      comboBoxMainResolution.SelectedIndex = getCbIndexMainReso(iIdxMain);
      //d40-43
      int iIdxAux = Convert.ToInt32(buf[44] << 24)
               + Convert.ToInt32(buf[45] << 16)
               + Convert.ToInt32(buf[46] << 8)
               + Convert.ToInt32(buf[47] << 0);
      comboBoxAuxResolution.SelectedIndex = getCbIndexAuxReso(iIdxAux);
      //d44
      if ((buf[48] & 0x01) == 0x01)
        checkBox3D.Checked = true;
      else
        checkBox3D.Checked = false;
      if ((buf[48] & 0x02) == 0x02)
          checkBoxStreamingOff.Checked = true;
      else
          checkBoxStreamingOff.Checked = false;
      //d45-48
      uint iOperatingHours = Convert.ToUInt32(buf[49] << 24)
                          + Convert.ToUInt32(buf[50] << 16)
                          + Convert.ToUInt32(buf[51] << 8)
                          + Convert.ToUInt32(buf[52] << 0);
      textBoxOperatingHours.Text = iOperatingHours.ToString();
      //d49-52
      uint iStandbyHours = Convert.ToUInt32(buf[53] << 24)
                          + Convert.ToUInt32(buf[54] << 16)
                          + Convert.ToUInt32(buf[55] << 8)
                          + Convert.ToUInt32(buf[56] << 0);
      textBoxStandbyHours.Text = iStandbyHours.ToString();
      //d53-56
      uint iLamp1Hours = Convert.ToUInt32(buf[57] << 24)
                          + Convert.ToUInt32(buf[58] << 16)
                          + Convert.ToUInt32(buf[59] << 8)
                          + Convert.ToUInt32(buf[60] << 0);
      textBoxLamp1Hours.Text = iLamp1Hours.ToString();
      //d57-60
      uint iLamp2Hours = Convert.ToUInt32(buf[61] << 24)
                          + Convert.ToUInt32(buf[62] << 16)
                          + Convert.ToUInt32(buf[63] << 8)
                          + Convert.ToUInt32(buf[64] << 0);
      textBoxLamp2Hours.Text = iLamp2Hours.ToString();
      //d61-64
      if ((buf[65] & 0x80) == 0x80)
        checkBoxFpValid.Checked = true;
      else
        checkBoxFpValid.Checked = false;
      if ((buf[68] & 0x80) == 0x80)
          checkBoxFpWlan.Checked = true;
      else
          checkBoxFpWlan.Checked = false;
      if ((buf[68] & 0x40) == 0x40)
        checkBoxFpStreaming.Checked = true;
      else
        checkBoxFpStreaming.Checked = false;
      if ((buf[68] & 0x20) == 0x20)
        checkBoxFpPip.Checked = true;
      else
        checkBoxFpPip.Checked = false;
      if ((buf[68] & 0x10) == 0x10)
        checkBoxFpIrRemote.Checked = true;
      else
        checkBoxFpIrRemote.Checked = false;
      if ((buf[68] & 0x08) == 0x08)
        checkBoxFpIntMemory.Checked = true;
      else
        checkBoxFpIntMemory.Checked = false;
      if ((buf[68] & 0x04) == 0x04)
        checkBoxFpUsbHost.Checked = true;
      else
        checkBoxFpUsbHost.Checked = false;
      if ((buf[68] & 0x02) == 0x02)
        checkBoxFpFading.Checked = true;
      else
        checkBoxFpFading.Checked = false;
      if ((buf[68] & 0x01) == 0x01)
          checkBoxFp60Fps.Checked = true;
      else
          checkBoxFp60Fps.Checked = false;
      if ((buf[67] & 0x01) == 0x01)
          checkBoxFpvConnect.Checked = true;
      else
          checkBoxFpvConnect.Checked = false;
      //d65
      comboBoxRecording.SelectedIndex = (buf[69] & 0xC0) >> 6;
      comboBoxPlayback.SelectedIndex = (buf[69] & 0x30) >> 4;
      comboBoxSource2.SelectedIndex = buf[69] & 0x0F;
      if ((buf[70] & 0x01) == 0x01)
          checkBoxMute.Checked = true;
      else
          checkBoxMute.Checked = false;
    }

    /**
     * Convert Wolfprot parameter to combobox index
     * @param iIdx: Wolfprot parameter
     * @return combobox index
     */
    private int getCbIndexMainReso(int iIdx)
    {
      switch (iIdx)
      {
        case 0x00000000:
          return 0;
        case 0x00003C01:
          return 1;
        case 0x00003C04:
          return 2;
        case 0x00003C08:
          return 3;
        case 0x00003C0A:
          return 4;
        case 0x00003C0D:
          return 5;
        case 0x00003C12:
          return 6;
        case 0x00003C14:
          return 7;
        case 0x00003C16:
          return 8;
        case 0x00003C18:
          return 9;
        case 0x00003C1C:
          return 10;
        case 0x00003C1E:
          return 11;
        case 0x00011818:
          return 12;
        case 0x00011E18:
          return 13;
        case 0x00021818:
          return 14;
        case 0x00021E18:
          return 15;
        case 0x00023C18:
          return 16;
        case 0x00031E18:
          return 17;
        case 0x00033C18:
          return 18;
        case 0x00041E18:
          return 19;
        case 0x00043C18:
          return 20;
        case 0x00051E18:
          return 21;
        case 0x00053C18:
          return 22;
        case 0x00131E18:
          return 23;
        case 0x00133C18:
          return 24;
        case 0x00141E18:
          return 25;
        case 0x00143C18:
          return 26;
        default:
          return 0;
      }
    }

    /**
     * Convert Wolfprot parameter to combobox index
     * @param iIdx: Wolfprot parameter
     * @return combobox index
     */
    private int getCbIndexAuxReso(int iIdx)
    {
      switch (iIdx)
      {
        case 0x00000000:
          return 0;
        case 0x00003C01:
          return 1;
        case 0x00003C04:
          return 2;
        case 0x00003C08:
          return 3;
        case 0x00003C0A:
          return 4;
        case 0x00003C0D:
          return 5;
        case 0x00003C12:
          return 6;
        case 0x00003C14:
          return 7;
        case 0x00003C16:
          return 8;
        case 0x00003C18:
          return 9;
        case 0x00003C1C:
          return 10;
        case 0x00003C1E:
          return 11;
        case 0x00101E18:
          return 12;
        case 0x00103C18:
          return 13;
        case 0x00111E18:
          return 14;
        case 0x00113C18:
          return 15;
        case 0x00121E18:
          return 16;
        case 0x00123C18:
          return 17;
        default:
          return 0;
      }
    }

    private void FormFlagsAndUnits_FormClosing(object sender, FormClosingEventArgs e)
    {
      timerFlagsAndUnits.Stop();
      connClose();
    }

    private void label52_Click(object sender, EventArgs e)
    {

    }

  }
}
