﻿
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace VZInterfaceTestHandbook
{
  public partial class FormHeightAdjustment : Form
  {
    int heigthadjuststep = 0;
    IComIf comIf;
    Boolean isConnected = false;

    public FormHeightAdjustment(IComIf com)
    {
      comIf = com;
      InitializeComponent();
    }

    /**
     * Open connection
     * @return success = false
     */
    private Boolean connOpen()
    {
      if (comIf.Open())
      {
        MessageBox.Show("Couldn´t open interface!", "Error",
                        MessageBoxButtons.OK,
                        MessageBoxIcon.Error);
        return true;
      }
      isConnected = true;
      return false;
    }

    /**
     * Close connection
     */
    private void connClose()
    {
      if (isConnected)
        comIf.Close();
      isConnected = false;
    }

    private void buttonReturn_Click(object sender, EventArgs e)
    {
      if (buttonReturn.Text == "Return")
      {
        connClose();
        Close();
        return;
      }
      if (buttonReturn.Text == "Cancel")
      {
        Heightadjustment heightadj = new Heightadjustment(comIf);
        heightadj.Cancel();

        StartFormSettings();
        connClose();
        return;
      }
    }

    private void buttonAccept_Click(object sender, EventArgs e)
    {
      // Initialize the commands
      Heightadjustment heightadj = new Heightadjustment(comIf);
      if (heightadj.Accept())
      {
        StartFormSettings();
        connClose();
      }
      else
      {
        if (buttonAccept.Text == "Next")
        {
          // Increment statemachine
          heigthadjuststep++;

          if (heigthadjuststep == 1)
            CameraFocusControl();
          else if (heigthadjuststep == 2)
            LightFocusControl();
          else
          {
            DialogResult result = MessageBox.Show("Accept result?", "Question",
                                                  MessageBoxButtons.YesNo);
            if (result == DialogResult.Yes)
              heightadj.Accept();
            else
              heightadj.Cancel();

            StartFormSettings();
            connClose();
          }
        }
        else
        {
          StartFormSettings();
          connClose();
        }
      }
    }

    private void buttonStartAutoAdjustment_Click(object sender, EventArgs e)
    {
      // Buttons to disable
      buttonStartAutoAdjustment.Enabled = false;
      buttonStartManualAdjustment.Enabled = false;

      // Change text of buttons
      buttonReturn.Text = "Cancel";

      // Start auto heigth adjustment
      Heightadjustment heightadj = new Heightadjustment(comIf);
      /*Open interface*/
      if (connOpen())
        return;
      heightadj.StartAutoAdjustment();

      // Start timer event
      timerAutoHeightAdj.Enabled = true;
    }

    private void buttonStartManualAdjustment_Click(object sender, EventArgs e)
    {
      // Change the contents of the form
      LightMirrorControl();

      /*Open interface*/
      if (connOpen())
        return;
      // Start the manual height adjustment
      Heightadjustment heightadj = new Heightadjustment(comIf);
      heightadj.StartManualAdjustment();
    }

    private void LightMirrorControl()
    {
      // Buttons to disable
      buttonStartAutoAdjustment.Enabled = false;
      buttonStartManualAdjustment.Enabled = false;
      buttonFocusFar.Enabled = false;
      buttonFocusNear.Enabled = false;

      // Buttons to enable
      buttonUp.Enabled = true;
      buttonDown.Enabled = true;
      buttonLeft.Enabled = true;
      buttonRight.Enabled = true;
      buttonAccept.Enabled = true;

      // Change text of button
      buttonAccept.Text = "Next";
      buttonReturn.Text = "Cancel";

      // Change text of label for introduction
      introduction.Text = "Center light field on screen using buttons "
                          + "\n(Up, Down, Right, Left). "
                          + "Use button \"Next\"\n to go "
                          + "to next step";
    }

    private void LightFocusControl()
    {
      // Buttons to disable
      buttonStartAutoAdjustment.Enabled = false;
      buttonStartManualAdjustment.Enabled = false;
      buttonUp.Enabled = false;
      buttonDown.Enabled = false;
      buttonLeft.Enabled = false;
      buttonRight.Enabled = false;

      // Buttons to enable
      buttonFocusFar.Enabled = true;
      buttonFocusNear.Enabled = true;
      buttonAccept.Enabled = true;

      // Change text of label for introduction and of the accept button
      introduction.Text = "Use \"Focus\" buttons (Focus Far/Near) \n"
                          + "to focus light onto working surface.";
    }

    private void CameraFocusControl()
    {
      // Buttons to disable
      buttonStartAutoAdjustment.Enabled = false;
      buttonStartManualAdjustment.Enabled = false;
      buttonUp.Enabled = false;
      buttonDown.Enabled = false;
      buttonLeft.Enabled = false;
      buttonRight.Enabled = false;

      // Buttons to enable
      buttonFocusFar.Enabled = true;
      buttonFocusNear.Enabled = true;
      buttonAccept.Enabled = true;

      // Change text of label for introduction
      introduction.Text = "Use \"Focus\" buttons (Focus Far/Near)\n"
                          + "to focus image onto working surface.";
    }

    private void StartFormSettings()
    {
      // Reset the state machine
      heigthadjuststep = 0;

      // Disable the timer event
      timerAutoHeightAdj.Enabled = false;

      // Buttons to disable
      buttonFocusFar.Enabled = false;
      buttonFocusNear.Enabled = false;
      buttonUp.Enabled = false;
      buttonDown.Enabled = false;
      buttonLeft.Enabled = false;
      buttonRight.Enabled = false;
      buttonAccept.Enabled = false;

      // Buttons to enable
      buttonStartAutoAdjustment.Enabled = true;
      buttonStartManualAdjustment.Enabled = true;


      // Change text of label for introduction
      introduction.Text = "Choose which kind of adjustment you wish";

      // Change text of buttons
      buttonReturn.Text = "Return";
      buttonAccept.Text = "Accept";
    }
    #region Movementbuttons

    private void timerAutoHeightAdj_Tick(object sender, EventArgs e)
    {
      String strState;
      int iTime;
      Heightadjustment heightadj = new Heightadjustment(comIf);
      strState = heightadj.GetHeightAdjustmentState();
      iTime = heightadj.GetTimeLeft();
      if ((strState == "") || (iTime == -1))
      {
        return;
      }
      labelState.Text = "State:" + strState;
      labelTimer.Text = "Time left:" + iTime.ToString() + "s";

      if (strState == "Done")
      {
        // Change text of labels
        introduction.Text = "Accept result?";
        labelState.Text = "";
        labelTimer.Text = "";

        // Buttons to enable
        buttonAccept.Enabled = true;
      }
    }

    private void buttonUp_MouseDown(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 30;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      heightadj.MirrorUp(speed);
    }

    private void buttonLeft_MouseDown(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 30;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      heightadj.MirrorLeft(speed);
    }

    private void buttonRight_MouseDown(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 30;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      heightadj.MirrorRight(speed);
    }

    private void buttonDown_MouseDown(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 30;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      heightadj.MirrorDown(speed);
    }

    private void buttonUp_MouseUp(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 0;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      heightadj.MirrorUp(speed);
    }

    private void buttonLeft_MouseUp(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 0;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      heightadj.MirrorLeft(speed);
    }

    private void buttonRight_MouseUp(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 0;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      heightadj.MirrorRight(speed);
    }

    private void buttonDown_MouseUp(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 0;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      heightadj.MirrorDown(speed);
    }

    #endregion

    private void buttonFocusFar_MouseDown(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speedcam = 10;
      Byte speedlight = 2;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      if (heigthadjuststep == 1)
        heightadj.CameraFocusFar(speedcam);
      else
        heightadj.LightFocusFar(speedlight);
    }

    private void buttonFocusNear_MouseDown(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speedcam = 10;
      Byte speedlight = 2;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      if (heigthadjuststep == 1)
        heightadj.CameraFocusNear(speedcam);
      else
        heightadj.LightFocusNear(speedlight);
    }

    private void buttonFocusFar_MouseUp(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 0;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      if (heigthadjuststep == 1)
        heightadj.CameraFocusFar(speed);
      else
        heightadj.LightFocusFar(speed);
    }

    private void buttonFocusNear_MouseUp(object sender, MouseEventArgs e)
    {
      // Define speed
      Byte speed = 0;

      Heightadjustment heightadj = new Heightadjustment(comIf);
      if (heigthadjuststep == 1)
        heightadj.CameraFocusNear(speed);
      else
        heightadj.LightFocusNear(speed);
    }

    private void FormHeightAdjustment_FormClosing(object sender, FormClosingEventArgs e)
    {
      timerAutoHeightAdj.Stop();
      connClose();
    }
  }
}
