﻿
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace VZInterfaceTestHandbook
{
  public partial class FormMultiUnicast : Form
  {
    Boolean formloader = false;
    IComIf comIf;
    Boolean isConnected = false;

    public FormMultiUnicast(IComIf com)
    {
      comIf = com;
      InitializeComponent();
    }

    /**
     * Open connection
     * @return success = false
     */
    private Boolean connOpen()
    {
      if (comIf.Open())
      {
        MessageBox.Show("Couldn´t open interface!", "Error",
                        MessageBoxButtons.OK,
                        MessageBoxIcon.Error);
        return true;
      }
      isConnected = true;
      return false;
    }

    /**
     * Close connection
     */
    private void connClose()
    {
      if (isConnected)
        comIf.Close();
      isConnected = false;
    }

    private void buttonStartUnicast_Click(object sender, EventArgs e)
    {
      // Send command
      MultiUnicast multiUnicast = new MultiUnicast(comIf);
      if (connOpen())
        return;
      multiUnicast.Start();
      connClose();
    }

    private void buttonStopUnicast_Click(object sender, EventArgs e)
    {
      // Send command
      MultiUnicast multiUnicast = new MultiUnicast(comIf);
      if (connOpen())
        return;
      multiUnicast.Stop();
      connClose();
    }

    private void comboBoxMode_SelectedIndexChanged(object sender, EventArgs e)
    {
      if (!formloader)
      {
        buttonStartUnicast.Enabled = false;
        buttonStopUnicast.Enabled = false;
        // Convert the item of combobox to needed byte
        Byte mode = 0x00;
        if (comboBoxMode.SelectedItem.ToString() == "OFF")
          mode = 0x00;
        else if (comboBoxMode.SelectedItem.ToString() == "AUTO")
          mode = 0x01;
        else if (comboBoxMode.SelectedItem.ToString() == "CONTINUOUS")
          mode = 0x02;
        else
        {
          mode = 0x03;
          buttonStartUnicast.Enabled = true;
          buttonStopUnicast.Enabled = true;
        }
        // Send command
        MultiUnicast multiUnicast = new MultiUnicast(comIf);
        if (connOpen())
          return;
        multiUnicast.MultiUnicastMode(mode);
        connClose();
      }
    }

    private void comboBoxPort_SelectedIndexChanged(object sender, EventArgs e)
    {
      if (!formloader)
      {
        // Convert the item of the combobox to an integer
        int intPort = Convert.ToInt32(comboBoxPort.SelectedItem);
        Byte[] port = new Byte[2];
        // Convert the integer into a byte array
        port[0] = Convert.ToByte((intPort & 0x0000FF00) >> 8);
        port[1] = Convert.ToByte(intPort & 0x000000FF);
        // Send command
        MultiUnicast multiUnicast = new MultiUnicast(comIf);
        if (connOpen())
          return;
        multiUnicast.MultiUnicastPort(port);
        connClose();
      }
    }

    private void comboBoxMultiIP1_SelectedIndexChanged(object sender, EventArgs e)
    {
      if (!formloader)
      {
        // Convert the items of the comboboxes to a byte array
        Byte[] ip = new Byte[4]; ;
        ip[0] = Convert.ToByte(comboBoxMultiIP1.SelectedItem);
        ip[1] = Convert.ToByte(comboBoxMultiIP2.SelectedItem);
        ip[2] = Convert.ToByte(comboBoxMultiIP3.SelectedItem);
        ip[3] = Convert.ToByte(comboBoxMultiIP4.SelectedItem);
        // Send command
        MultiUnicast multiUnicast = new MultiUnicast(comIf);
        if (connOpen())
          return;
        multiUnicast.MulticastIPAddress(ip);
        connClose();
      }
    }

    private void comboBoxMultiIP2_SelectedIndexChanged(object sender, EventArgs e)
    {
      if (!formloader)
      {
        // Convert the items of the comboboxes to a byte array
        Byte[] ip = new Byte[4]; ;
        ip[0] = Convert.ToByte(comboBoxMultiIP1.SelectedItem);
        ip[1] = Convert.ToByte(comboBoxMultiIP2.SelectedItem);
        ip[2] = Convert.ToByte(comboBoxMultiIP3.SelectedItem);
        ip[3] = Convert.ToByte(comboBoxMultiIP4.SelectedItem);
        // Send command
        MultiUnicast multiUnicast = new MultiUnicast(comIf);
        if (connOpen())
          return;
        multiUnicast.MulticastIPAddress(ip);
        connClose();
      }
    }

    private void comboBoxMultiIP3_SelectedIndexChanged(object sender, EventArgs e)
    {
      if (!formloader)
      {
        // Convert the items of the comboboxes to a byte array
        Byte[] ip = new Byte[4]; ;
        ip[0] = Convert.ToByte(comboBoxMultiIP1.SelectedItem);
        ip[1] = Convert.ToByte(comboBoxMultiIP2.SelectedItem);
        ip[2] = Convert.ToByte(comboBoxMultiIP3.SelectedItem);
        ip[3] = Convert.ToByte(comboBoxMultiIP4.SelectedItem);
        // Send command
        MultiUnicast multiUnicast = new MultiUnicast(comIf);
        if (connOpen())
          return;
        multiUnicast.MulticastIPAddress(ip);
        connClose();
      }
    }

    private void comboBoxMultiIP4_SelectedIndexChanged(object sender, EventArgs e)
    {
      if (!formloader)
      {
        // Convert the items of the comboboxes to a byte array
        Byte[] ip = new Byte[4]; ;
        ip[0] = Convert.ToByte(comboBoxMultiIP1.SelectedItem);
        ip[1] = Convert.ToByte(comboBoxMultiIP2.SelectedItem);
        ip[2] = Convert.ToByte(comboBoxMultiIP3.SelectedItem);
        ip[3] = Convert.ToByte(comboBoxMultiIP4.SelectedItem);
        // Send command
        MultiUnicast multiUnicast = new MultiUnicast(comIf);
        if (connOpen())
          return;
        multiUnicast.MulticastIPAddress(ip);
        connClose();
      }
    }

    private void FormMultiUnicast_Load(object sender, EventArgs e)
    {
      // Set formloader true speed up
      // loading of form
      formloader = true;
      // Clear comboboxes
      comboBoxPort.Items.Clear();
      comboBoxMode.Items.Clear();
      if (connOpen())
        return;
      // Call the method MultiUnicast
      MultiUnicast multiUnicast = new MultiUnicast(comIf);

      // Set new values into combo box for port
      for (int i = 0; i <= 100; i++)
      {
        comboBoxPort.Items.Add(8800 + i * 2);
      }
      // Get current port from the visualizer
      Byte[] getPort = multiUnicast.GetPort();
      // Set start index of the combobox
      comboBoxPort.SelectedIndex = comboBoxPort.Items.IndexOf(getPort[0] * 256 + getPort[1]);

      // Set new values into combo box for mode
      comboBoxMode.Items.Add("OFF");
      comboBoxMode.Items.Add("AUTO");
      comboBoxMode.Items.Add("CONTINUOUS");
      comboBoxMode.Items.Add("UNICAST");

      // Find out which mode is currently on the visualizer
      Byte getMode = multiUnicast.GetMode();
      string strmode = "";
      if (getMode == 0x00)
        strmode = "OFF";
      else if (getMode == 0x01)
        strmode = "AUTO";
      else if (getMode == 0x02)
        strmode = "CONTINUOUS";
      else
        strmode = "UNICAST";

      // Set the startindex of the combobox
      comboBoxMode.SelectedIndex = comboBoxMode.Items.IndexOf(strmode);

      // set new values for the multicast ip 
      for (int i = 0; i < 256; i++)
      {
        if (i < 14)
          comboBoxMultiIP1.Items.Add(225 + i);

        comboBoxMultiIP2.Items.Add(i);
        comboBoxMultiIP3.Items.Add(i);
        comboBoxMultiIP4.Items.Add(i);
      }

      // Get the current multicast ip
      Byte[] getMulitcastIP = multiUnicast.GetMulticastIP();

      // Set the startindexes for the comboboxes
      comboBoxMultiIP1.SelectedIndex = comboBoxMultiIP1.Items.IndexOf
                                      (Convert.ToInt32(getMulitcastIP[0]));
      comboBoxMultiIP2.SelectedIndex = comboBoxMultiIP2.Items.IndexOf
                                      (Convert.ToInt32(getMulitcastIP[1]));
      comboBoxMultiIP3.SelectedIndex = comboBoxMultiIP3.Items.IndexOf
                                      (Convert.ToInt32(getMulitcastIP[2]));
      comboBoxMultiIP4.SelectedIndex = comboBoxMultiIP4.Items.IndexOf
                                      (Convert.ToInt32(getMulitcastIP[3]));

      // Set formloader false to 
      // show that loading has finished
      formloader = false;
      connClose();
    }
  }
}
