﻿
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace VZInterfaceTestHandbook
{
  /**
   * GET/SET Zoom example
   */
  public partial class FormZoomSettings : Form
  {
    IComIf comIf;
    Boolean isConnected = false;

    /**
    * @param com: uses Interface IComIf
    */
    public FormZoomSettings(IComIf com)
    {
      InitializeComponent();
      comIf = com;
      ZoomSettings zS = new ZoomSettings(comIf);    // makes the command
      // Sets the trackbar on new Value
      if (connOpen())
        return;
      trackBarZoomPos.Value = Convert.ToInt32(zS.ZoomSliderGetPos(trackBarZoomPos));
      connClose();
      labelActPos.Text = trackBarZoomPos.Value.ToString();
    }

    /**
     * Open connection
     * @return success = false
     */
    private Boolean connOpen()
    {
      if (comIf.Open())
      {
        MessageBox.Show("Couldn´t open interface!", "Error",
                        MessageBoxButtons.OK,
                        MessageBoxIcon.Error);
        return true;
      }
      isConnected = true;
      return false;
    }

    /**
     * Close connection
     */
    private void connClose()
    {
      if (isConnected)
        comIf.Close();
      isConnected = false;
    }

    private void buttonStartZoomTele_Click(object sender, EventArgs e)
    {
      ZoomSettings zS = new ZoomSettings(comIf);              // makes the command
      if (connOpen())
        return;
      zS.StartZoomTele();                                     // Initialize the new command
      connClose();
    }

    //@@@START_BUTTONSTARTZOOMWIDE@@@
    private void buttonStartZoomWide_Click(object sender, EventArgs e)
    {
      /*Instantiate class*/
      ZoomSettings zS = new ZoomSettings(comIf);
      /*Open interface*/
      if (connOpen())
        return;
      /*Send command*/
      zS.StartZoomWide();
      /*Close interface*/
      connClose();
    }
    //@@@STOP_BUTTONSTARTZOOMWIDE@@@

    private void trackBarZoomSpeed_MouseUp(object sender, MouseEventArgs e)
    {
      trackBarZoomSpeed.Value = 0;                            // Sets the trackbar on Value 0
      ZoomSettings zS = new ZoomSettings(comIf);              // makes the command
      if (connOpen())
        return;
      zS.ZoomSliderSpeed(trackBarZoomSpeed);                  // Initialize the new command
      // Sets the trackbar(zoomPos) on new Value
      trackBarZoomPos.Value = zS.ZoomSliderGetPos(trackBarZoomPos);
      connClose();
      labelActPos.Text = trackBarZoomPos.Value.ToString();    // change text of label to position
    }

    //@@@START_TRACKBARZOOMSPEED@@@
    private void trackBarZoomSpeed_Scroll(object sender, EventArgs e)
    {
      /*Instantiate class*/
      ZoomSettings zS = new ZoomSettings(comIf);
      /*Open interface*/
      if (connOpen())
        return;
      /*Send command*/
      zS.ZoomSliderSpeed(trackBarZoomSpeed);
      // Sets the trackbar(zoomPos) on new Value
      trackBarZoomPos.Value = zS.ZoomSliderGetPos(trackBarZoomPos);
      /*Close interface*/
      connClose();
      labelActPos.Text = trackBarZoomPos.Value.ToString();    // change text of label to position
    }
    //@@@STOP_TRACKBARZOOMSPEED@@@

    //@@@START_TRACKBARZOOMPOS@@@
    private void trackBarZoomPos_Scroll(object sender, EventArgs e)
    {
      /*Instantiate class*/
      ZoomSettings zS = new ZoomSettings(comIf);
      /*Open interface*/
      if (connOpen())
        return;
      /*Send command*/
      zS.ZoomSliderSetPos(trackBarZoomPos);
      /*Close interface*/
      connClose();
      labelActPos.Text = trackBarZoomPos.Value.ToString();    // change text of label to position
    }
    //@@@STOP_TRACKBARZOOMPOS@@@

    private void buttonReturn_Click(object sender, EventArgs e)
    {
      connClose();
      Close();
    }

    //@@@START_BUTTONUPDATE@@@
    private void buttonUpdate_Click(object sender, EventArgs e)
    {
      // Sets the trackbar on new Value
      /*Instantiate class*/
      ZoomSettings zS = new ZoomSettings(comIf);
      /*Open interface*/
      if (connOpen())
        return;
      /*Send command*/
      trackBarZoomPos.Value = zS.ZoomSliderGetPos(trackBarZoomPos);
      /*Close interface*/
      connClose();
      labelActPos.Text = trackBarZoomPos.Value.ToString();    // change text of label to position
    }
    //@@@STOP_BUTTONUPDATE@@@

    private void buttonZoomStop_Click(object sender, EventArgs e)
    {
      /*Instantiate class*/
      ZoomSettings zS = new ZoomSettings(comIf);
      /*Open interface*/
      if (connOpen())
        return;
      /*Send command*/
      zS.StopZoom();
      /*Close interface*/
      connClose();
    }
  }
}
