using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace VZInterfaceTestHandbook
{
  public class USBManager
  {
    private static WinUsbNet.UsbDevice m_currUSBDevice;
    public static bool IsWolProtAvailable;
    public static WinUsbNet.WinUsbManager USBMan = new WinUsbNet.WinUsbManager(new Guid("{719445b5-dd1b-4440-bf16-52584c8666da}"));
    public static WinUsbNet.UsbDevice currUSBDevice
    {
      get
      {
        return m_currUSBDevice;
      }
      set
      {
        m_currUSBDevice = value;
        SendPipe = null;
        ReceivePipe = null;

        try
        {
          if (!m_currUSBDevice.IsOpen)
            m_currUSBDevice.Open();


          if (m_currUSBDevice.PipeStreams != null)
          {
            foreach (WinUsbNet.PipeStream pipe in m_currUSBDevice.PipeStreams)
            {
              if (pipe != null)
              {
                if (pipe.CanRead && pipe.CanWrite)
                {
                  ReceivePipe = pipe;
                  SendPipe = pipe;
                }
                else if (pipe.CanRead && ReceivePipe == null)
                  ReceivePipe = pipe;
                else if (pipe.CanWrite && SendPipe == null)
                  SendPipe = pipe;

                if (SendPipe != null && ReceivePipe != null)
                {
                  SendPipe.WriteTimeout = 1000;
                  SendPipe.WriteUseShortPacket = true;
                  ReceivePipe.ReadTimeout = 2000;
                  ReceivePipe.ReadUseShortPacket = true;
                  break;
                }
              }
            }
          }
        }
        catch (Exception)
        {
          Console.Write("Error while trying to set up USB device");
        }
      }

    }
    public static WinUsbNet.PipeStream SendPipe;

    public static WinUsbNet.PipeStream ReceivePipe;

    public static uint USBFindAllDevs()
    {
      foreach (WinUsbNet.UsbDevice usb in USBMan.UsbDevices)
      {
        usb.Close();        
      }
      USBMan = new WinUsbNet.WinUsbManager(new Guid("{719445b5-dd1b-4440-bf16-52584c8666da}"));
      if (USBMan.UsbDevices.Count > 0) currUSBDevice = USBMan.UsbDevices[0];      
      return Convert.ToUInt32(USBMan.UsbDevices.Count);
    }

    public static string GetTypeSerialVersion(WinUsbNet.UsbDevice usbDev)
    {
      String DeviceName = null;
      String Version = null;
      String Serialnumber = null;
      Byte[] locArray = new Byte[256];
      Byte[] locProt2Send;
      Byte[] locRecv;

      UsbCom comUSB = new UsbCom();
      locProt2Send = new byte[3];
      locProt2Send[0] = 0x0;
      locProt2Send[1] = 0x11;
      locProt2Send[2] = 0x0;

      comUSB.Write(locProt2Send, locProt2Send.Length);

      locRecv = new Byte[259];
      comUSB.Read(ref locRecv);

      if (locRecv[2].Equals(0x6) && locRecv[0].Equals(0x1) && locRecv[1].Equals(0x0))
      {
        locProt2Send[0] = 0x42;
        locProt2Send[1] = 0x0;
        locProt2Send[2] = 0x2;
        locProt2Send[3] = 0xE;
        locProt2Send[4] = 0x0;
        locProt2Send[5] = 0x0;
        locProt2Send[6] = 0x0;
        locProt2Send[7] = 0x0;
        USBManager.IsWolProtAvailable = false;

        comUSB.Write(locProt2Send, locProt2Send.Length);

        locRecv = new Byte[259];
        comUSB.Read(ref locRecv);
        Console.WriteLine("Device does not support WolfProt");
        return String.Empty;
      }
      else
      {
        //DeviceType
        Array.Resize(ref locArray, locRecv[2]);
        Array.Copy(locRecv, 3, locArray, 0, locRecv[2]);
        USBManager.IsWolProtAvailable = true;
        DeviceName = Encoding.UTF8.GetString(locArray);


        //Version
        locProt2Send = new Byte[3];
        locProt2Send[0] = 0x0;
        locProt2Send[1] = 0x13;
        locProt2Send[2] = 0x0;

        comUSB.Write(locProt2Send, locProt2Send.Length);

        locRecv = new byte[259];
        comUSB.Read(ref locRecv);
        locArray = new Byte[256];

        if (locRecv[0].Equals(0x0) && locRecv[1].Equals(0x13))
        {
          Array.Resize(ref locArray, locRecv[2]);
          Array.Copy(locRecv, 3, locArray, 0, locRecv[2]);
          Version = Encoding.UTF8.GetString(locArray);
        }

        //Serialnumber
        locProt2Send = new Byte[3];
        locProt2Send[0] = 0x0;
        locProt2Send[1] = 0x12;
        locProt2Send[2] = 0x0;

        comUSB.Write(locProt2Send, locProt2Send.Length);

        locRecv = new byte[259];
        comUSB.Read(ref locRecv);
        locArray = new Byte[256];

        if (locRecv[0].Equals(0x0) && locRecv[1].Equals(0x12) && locRecv[2].Equals(0x4))
        {
          Array.Resize(ref locArray, locRecv[2]);
          Array.Copy(locRecv, 3, locArray, 0, locRecv[2]);
          int serial = ((int)locArray[0] << 24) + ((int)locArray[1] << 16) + ((int)locArray[2] << 8) + locArray[3];


          switch (serial.ToString().Length)
          {
            case 0:
              Serialnumber = "";
              break;
            case 1:
              Serialnumber = "0000000" + serial.ToString();
              break;
            case 2:
              Serialnumber = "000000" + serial.ToString();
              break;
            case 3:
              Serialnumber = "00000" + serial.ToString();
              break;
            case 4:
              Serialnumber = "0000" + serial.ToString();
              break;
            case 5:
              Serialnumber = "000" + serial.ToString();
              break;
            case 6:
              Serialnumber = "00" + serial.ToString();
              break;
            case 7:
              Serialnumber = "0" + serial.ToString();
              break;
          }

        }

        return DeviceName + ";" + Serialnumber + ";" + Version;
      }
    }
  }
}
